**************************************************
**Syntax producing the USA heritage time use    **
**background files for 1985                     **
**written by Kimberly Fisher & Nuno Torres      **
**Institute for Social and Economic Research    **
**University of Essex, Wivenhoe Park Colchester **
**United Kingdom                                **
**15 May 2006                                   **
**************************************************.

*The first step in the code is to extract wagerate from another file (agmail85) into the usa85 file. 

**************************************************
*syntax to extract wage information from agmail85*
**************************************************.

get file ='O:\worked on data\1985\agmail85.sav'
  /keep hid sex age marital wkhrs educ wagerate.

rename vars (hid=hhid).
missing values all ().
recode age wkhrs (sysmiss=99).
recode sex marital educ (sysmiss=9).
fre sex.
select if sex=1 or sex=2.
execute.
sort cases by hhid sex age marital wkhrs educ.

save outfile='O:\worked on data\1985\old usa85,86,87 data\agmail85_wgerate.sav'.

*******************************************************
*save version of summary time use file to match in pid*
*this step necessary as original mail85 episode file  *
*misallocated background variables to the wrong pids  *
*in some households, so the match is made on diary    *
*elements                                             *
*******************************************************.

get file='Y:\all\USA\heritage_datasets\Harmonised files\Diary\diary1985\USA1985hfsum.sav'.

sort cases by hhid tmain3 tmain20 tmain22 tmain86. 

save outfile='O:\worked on data\1985\old usa85,86,87 data\USA1985hfsum.sav'.

*****************************************
*open base file for background variables*
*****************************************.

get file='Y:\all\USA\1985\usa85.sav'.

*check demographic variable distributions - see above note.
missing values all ().
freq sex age marital htype nwork wkhrs under5 under18 income 
     educ full part retired unemp student homemake other rururb.
desc daywt wt. 

sort cases by hhid sex age marital wkhrs educ.

match files files=* /in=usa85
      files='O:\worked on data\1985\old usa85,86,87 data\agmail85_wgerate.sav' /in=agmail
   /by hhid sex age marital wkhrs educ.
cro usa85 by agmail.

recode wagerate (sysmis=-8).

temp.
select if wagerate=-8.
cro usa85 by agmail.

sort cases by hhid(a) sex(a) agmail(d) usa85(a).

Do if hhid=lag(hhid) and sex=lag(sex) and age=lag(age).
   Do if usa85=1 and agmail=0.
      If (wkhrs=0 or wkhrs=99) and  (lag(wkhrs)>0 and lag(wkhrs)<99) wkhrs=lag(wkhrs).  
      if (wagerate=0 or wagerate=-8) and (lag(wagerate)>-1 and lag(wagerate)<99) wagerate=lag(wagerate). 
   End if.
End if.
execute.

temp.
select if wagerate=-8.
cro usa85 by agmail.

select if usa85=1.
freq usa85.

*************
*identifiers*
*************.

compute survey = 3.
compute wave = 1.

********
*pid
********.
*the summary file included the household level identifier, *
*but not an indidual identifier. To match the background   *
*variables to the diary variables, I used a combination of *
*diary variables.

compute tmain3 = ACT45.
compute tmain86 =  ACT91.
compute tmain20 =  ACT10.
compute tmain22 =  ACT12 + ACT13.
compute testid=0.
freq tmain3 tmain86 tmain20 tmain22.

sort cases by hhid tmain3 tmain86 tmain20 tmain22.
if hhid=lag(hhid) and tmain3=lag(tmain3) and tmain86=lag(tmain86) 
   and tmain20=lag(tmain20) and tmain22=lag(tmain22) testid=1.
*hhid and sleep alone uniquely identify all but 216 diaries; adding
*watch TV identifies all but 46 diaries; adding food preparation
*allows the unique identification of all but 2 diaries; adding
*cleaning allows for a unique match.
freq testid.

*there are 6 cases where error corrections in the diaries mean
*that this match won't work in these cases.
Do if hhid=797.
   recode tmain86 (155=170).
Else if hhid=7068 and tmain22=10.
   recode tmain3 (165=560).
   recode tmain20 (465=70).
Else if hhid=1466 and tmain3=420.
   compute tmain3=330.
Else if hhid=1466 and tmain3=450.
   compute tmain3=540.
   recode tmain22 (60=0).
   recode tmain86 (60=180).
Else if hhid=1547 and tmain3=195.
   recode tmain20 (10=25).
   recode tmain86 (0=120).
Else if hhid=1547 and tmain3=540.
   recode tmain20 (15=0).
   recode tmain86 (120=0).
End if.

*this sort needed to match to the diary files to obtain the PID.
sort cases by hhid tmain3 tmain20 tmain22 tmain86. 

*now matching with diary file (USA1985hfsum) to get the pid.

MATCH FILES /FILE=*
 /FILE='O:\worked on data\1985\old usa85,86,87 data\USA1985hfsum.sav'
 /BY hhid tmain3 tmain20 tmain22 tmain86.
desc pid.

**************************************
*COMPUTATION OF DEMOGRAPHIC VARIABLES*
**************************************.
compute regionc=-9.
compute regione =-9.
compute urban=rururb.
cro rururb by urban.

compute ownhome=-9.
compute state=-9.
fre age.
recode  age  (99=-8).
fre age.

recode age (18 thru 24=1) (25 thru 34=2) (35 thru 44=3) (45 thru 54=4) (55 thru 64=5) (65 thru highest=6) (-8=-8)
into agecat.
execute.
VARIABLE LABELS agecat "age categories".
VALUE LABELS agecat
-8 missing	
1 18 to 24	
2 25 to 34	
3 35 to 44	
4 45 to 54	
5 55 to 64	
6 65 plus.

cro age by agecat.
fre agecat.

fre sex.
compute ethnic=-9.
compute ethnic2=-9.
compute hisp=-9.
fre educ.
recode educ (9=-8) .
compute cohab=-9.
compute marrflag=-9.
fre age under18 under5.

compute famstat=-9.
do if under18=0 & (age>17 & age<40).
   compute famstat=0.
else if age>17 & under5>0.
   compute famstat=1.
else if age>17 & under5=0 & under18>0.
   compute famstat=2.
else if age>39 & under18=0.
   compute famstat=3.
else if age=-8..
   compute famstat=-8.
end if.
variable label FAMSTAT "Individual life cycle status".
value labels FAMSTAT
 -8 missing	
0 Adult 18 to 39, no co-resident child <18	
1 Adult 18+ living with co-resident child aged <5	
2 Adult 18+ living with co-resident child 5-17, no <5	
3 Adult 40+ no co-resident child <18.	
freq famstat. 
cro age by famstat.
cro htype by famstat.

fre htype.
compute hhtype=htype.
compute kidflag=-9.
fre under18.
cro htype by under18.

fre under5.
cro htype by under5.

compute ageyngst=-9.
compute nkidflag=-9.
compute disab=-9.

*********************************
*set-up for employment variables*
*********************************.

cro full by part.

*part-time should be coded from part regardless of the
*corresponding value in full. Full appears to mark
*employed as opposed to employed full-time.

temp.
select if wkhrs>0 and wkhrs<30. 
freq full part student retired.

*********************************************************
*290 people have part-time regular work hours. As there
*are some inconsistencies which do not appear to come 
*from the respondents but from the dataset, these are
*now corrected. All 132 people with a yes to part-time
*have low hours (even those who also have a yes to 
*full time), plus there are 78 additional people with 
*work hours and no to part time. Also, using this 
*formula produces a realistic distribution of part-time
*workers for 1985 - with this formula.
*             65-66  75-76  85   92-94  03
*% part-time   2.7    6.0   9.9  10.1  12.9
*********************************************************.

Do if wkhrs>0 and wkhrs<30.
   compute emp=2.
Else if full=0 and part=0.
   compute emp=4. 
Else if full=1.
   compute emp=1.
End if.
val lab emp
   1 full time
   2 part time
   4 not working.
freq emp.
cro wkhrs by emp.

*********
*empstat*
*********.
compute empstat=3.
if emp=1 empstat=1.
if emp=2 empstat=2.
var lab empstat "employment status of respondent".
val lab empstat
1 'employed full-time'
2 'employed part-time'
3 'not employed'
-8 'missing or dirty on the case record'
-9 'could not be constructed'
-3 'routed out in the 1992-94 survey'.

freq empstat.
cro emp by empstat.

compute occup=-9.
temp.
select if marital>1 and marital<9.
freq htype.

compute empsp=-8.
if marital>1 and marital<9 empsp=-7.
var lab empsp employment status of spouse.
val lab empsp
   -8 missing
   -7 no spouse
    1 "full-time"
    2 "part-time"
    3 unknown hours of work
    4 not working.
freq empsp.
compute m=0.
if marital=1 m=1.
AGGREGATE
  /outfile='O:\worked on data\1985\old usa85,86,87 data\usa85check.sav'
  /BREAK=hhid
  /ncoup = SUM(m)
  /ncase=n.
match files files=* 
      table='O:\worked on data\1985\old usa85,86,87 data\usa85check.sav'
   /BY hhid.
freq ncoup ncase.
cro ncoup by marital htype ncase.

*check if can improve on the coding of employment status of spouse.
temp.
select if ncoup=1 and ncase=2.
freq marital.

temp.
select if ncoup=1 and (ncase>2 and ncase<6).
freq marital hhid.

compute test=0.
if ncoup=1 and ncase=2 and marital=9 test=1.
freq test.

*if 2 people in household, household type is married
*couple household no kid and number of people in
*couple=1 and the marital status of 1 person is 
*missing - change the marital status from missing to
*married in these cases.
Do if test=1.
   compute marital=1.
   compute m=1.
End if.
freq marital.

compute test=0.
if ncoup=1 and ncase>2 and marital>1 test=1.
freq test.

if sex=1 emph=emp.
if sex=2 empw=emp.

AGGREGATE
  /outfile='O:\worked on data\1985\old usa85,86,87 data\usa85check2.sav'
  /BREAK=hhid
  /ncoup2 = SUM(m) /emph = MAX(emph)  /empw=MAX(empw).
match files files=* 
      table='O:\worked on data\1985\old usa85,86,87 data\usa85check2.sav'
   /BY hhid.
freq ncoup ncoup2 emph empw.

sort cases by hhid sex.
if empsp=-8 and ncoup2=2 and ncase=2 and sex=2 empsp=lag(emph).
sort cases by hhid sex(d).
if empsp=-8 and ncoup2=2 and ncase=2 and sex=1 empsp=lag(empw).
recode empsp (sysmis=-8).
freq empsp.

sort cases by hhid marital sex.
if empsp=-8 and hhid=lag(hhid) and marital=1 and ncoup2=2 and sex=2 empsp=lag(emph).
sort cases by hhid marital sex(d).
if empsp=-8 and hhid=lag(hhid) and marital=1 and ncoup2=2 and sex=1 empsp=lag(empw).
recode empsp (sysmis=-8).
freq empsp.

compute test=0.
if ncoup>2 and empsp=-8 test=1.
freq test.
*these 34 cases visually inspected and addressed.
Do if hhid=7594 and (age=62 or age=57).
   compute empsp=4.
Else if hhid=7594 and (age=24 or age=28).
   compute empsp=1.
*this household checked against the empsp in the
*episode file.
Else if hhid=7496 and (age=29 or age=28).
   compute empsp=1.
Else if hhid=7496 and age=26.
   compute empsp=1.
Else if hhid=7496 and age=25.
   compute empsp=4.
Else if hhid=7418 and age=51.
   compute empsp=1.
Else if hhid=7418.
   compute empsp=4.
Else if hhid=7200 and age=54.
   compute empsp=4.
Else if hhid=7112 and age>50.
   compute empsp=1.
Else if hhid=6180 and student=1.
   compute empsp=1.
Else if hhid=6180.
   compute empsp=4.
Else if hhid=1448 and day=7.
   compute empsp=4.
Else if hhid=1319 and marital=1.
   compute empsp=1.
Else if hhid=549 and age<40.
   compute empsp=1.
Else if hhid=517 and sex=1.
   compute empsp=2.
Else if hhid=517 and sex=2.
   compute empsp=1.
End if.
freq empsp.

temp.
select if empsp=-8.
freq ncoup2.

temp.
select if empsp=-8 and ncoup2=0.
freq marital.

*can go no further to compute empsp.

*NOTE marital status and number of adults included here
*as changes to create the employment status of the 
*spouse also affected these variables.

cro ncase by nwork. 

compute nadult=ncase.
if nwork>ncase nadult=nwork.
var lab nadult "number of adults in the household".
val lab nadult
  -9 "question not asked"
  -8 "missing or dirty in the case record"
  -7 "refusal"
  11 "more than 10".
freq nadult. 
cro nadult by ncase.

fre marital.

compute civstat=marital.
recode civstat (9=-8).
execute.
var label civstat "marital status".

value labels civstat
-9 not asked	
-8 missing	
1 Married	
2 Separated, divorced	
3 Widowed	
4 Never married.

fre civstat.
cro civstat by marital.

compute fulltime=0.
compute parttime=0.
compute noemploy=0.

if empstat=1 fulltime=1.
if empstat=2 parttime=1.
if empstat=3 noemploy=1.
cro empstat by fulltime parttime noemploy.   

****************
*unemp
*retired
*student present
*****************.
rename variables (homemake=homemakr).
recode unemp retired student homemakr
(sysmiss=-8).

fre unemp retdis student homemakr.

freq nwork.
fre wkhrs.
cro wkhrs by noemploy.
if noemploy=1 wkhrs=-7.

recode wkhrs (sysmiss=-8) (99=-8).
fre wkhrs.

*next code is just for inserting values in the codebook table.

recode wkhrs (0 thru 20 =1) (21 thru 30=2) (31 thru 40=3) (21 thru 50=4) (51 thru highest=5) (-7=-7) (-8=-8)
into twkhrs.
fre wkhrs.

compute empflag=-9.
compute wkhrflag=-9.
desc wkhrs wagerate.

do if wkhrs >=0 and wagerate>0.
	compute wagelm=(wagerate*wkhrs)*4.
else if wkhrs=-8 or wagerate=-8.
	compute wagelm=-8.
else if wkhrs=-7 or wagerate=0.
	compute wagelm=-7.
end if.
desc wagelm.

temp.
sel if wagelm>0.
desc wagelm.

if empstat=3 and wagelm=-8 wagelm=-7.

means wagelm by empstat
/cell mean median count min max.

fre income.

temp.
sel if income ne 54.
FREQUENCIES
  VARIABLES=income
  /NTILES=  4
  /ORDER=  ANALYSIS .

compute incomeqt=0.
if income <51 incomeqt=1.
if income >=51 and income <52 incomeqt=2.
if income >=52 and income<53 incomeqt=3.
if income>=53 and income<54 incomeqt=4.
if income=54 incomeqt=-8.

temp.
sel if incomeqt ne -8.
fre incomeqt.
compute income65=-9.
compute income75=-9.
compute income03=-9.

apply dictionary from 'Y:\all\USA\heritage_datasets\Harmonised files\Questionnaire\usa03quest.sav'.

*final checks.
freq survey wave state regionc regione urban ownhome sex ethnic ethnic2 hisp educ civstat
cohab marrflag famstat hhtype kidflag nadult under18 under5 ageyngst nkidflag fulltime 
parttime noemploy empstat occup unemp retired empsp disab student homemakr wkhrs nwork empflag 
wkhrflag incomeqt income65 income75 income03 agecat.
desc hhid pid age wagelm.

sort cases by survey wave hhid pid.

SAVE OUTFILE='O:\worked on data\1985\old usa85,86,87 data\USA1985questionnaire_FINAL_modified.sav'
  /keep survey wave hhid pid state regionc regione urban ownhome age sex ethnic ethnic2 hisp educ civstat
cohab marrflag famstat hhtype kidflag nadult under18 under5 ageyngst nkidflag fulltime parttime noemploy 
empstat occup unemp retired empsp disab student homemakr wkhrs nwork empflag wkhrflag wagelm incomeqt
income65 income75 income03.

