**************************************************
**Syntax producing the USA heritage time use    **
**demographic data file for the 1994-95 NHAPS   **
**extention, create by Dr. Kimberly Fisher,     **
**Centre for Time Use Research, Department of   **
**Sociology, University of Oxford               **
**Oxford OX1 3UQ United Kingdom                 **
**12 December 2009                              **
**************************************************.

GET FILE='C:\Documents and Settings\All Users\Documents\time-use-library\USA\1995\main95.sav'.

missing values all ().

recode day (1=2) (2=3) (3=4) (4=5) (5=6) (6=7) (7=1) 
   INTO diaryday.
compute month=trunc(date/10000).
compute year=(date-trunc(date/100)*100)+1900.
compute wave=1.
compute survey=5.
val lab survey
     0 "1965-66 USA Szalai Jackson sample"
     1 "1965-66 USA national sample"
     2 "1975-76 longitudinal survey"
     3 "1985 Univ Michigan survey"
     4 "1992-94 NHAPS survey"
     5 "1994-95 NHAPS extension survey"
     6 "1998-2001 SRC survey"
     7 "2003-2008 ATUS".
compute hhid=respid.
freq month diaryday year.
*the 1996 value is an error in one episode in the same diary.
recode year (1996=1995).
*check for related year inconsistencies.

AGGREGATE
  /OUTFILE=* MODE=ADDVARIABLES
  /BREAK=respid
  /minyear = MIN(year) /maxyear=MAX(year).
cro minyear by maxyear.
*fortunately this case was the only error.

*Convert var p1 - year of birth, into age.
Do if p1<88 and year=1995.
   compute age=95-p1.
Else if p1<88 and year=1994.
   compute age=94-p1.
Else.
   compute age=-8.
End if.
rename variables (respid rsex=pid sex).
freq sex age.

Recode age (18 thru 24=1) (25 thru 34=2) (35 thru 44=3)
       (45 thru 54=4) (55 thru 64=5) (65 thru high=6)
       (else=-8) INTO agecat.
var lab agecat age categorised to be consistent with census.
val lab agecat
  -9 not asked
  -8 missing
   1 18-24
   2 25-34
   3 35-44
   4 45-54
   5 55-64
   6 65 plus.
freq agecat.

*****************
*STATE & REGIONS*
*****************.

recode area (41=40)(42=41)(43=42)(44=43)(45=44)
     (46=45)(47=46)(49=47)(50=48)(51=49)(52=50)
     (53=51) (else=copy) into state.
val lab state
-9 data not available	
 1 ALABAMA	
 2 ALASKA	
 3 ARIZONA	
 4 ARKANSAS	
 5 CALIFORNIA	
 6 COLORADO	
 7 CONNECTICUT	
 8 DELAWARE	
 9 DISTRICT OF COLUMBIA	
10 FLORIDA	
11 GEORGIA	
12 HAWAII	
13 IDAHO	
14 ILLINOIS	
15 INDIANA	
16 IOWA	
17 KANSAS	
18 KENTUCKY	
19 LOUISIANA	
20 MAINE	
21 MARYLAND	
22 MASSACHUSETTS	
23 MICHIGAN	
24 MINNESOTA	
25 MISSISSIPPI	
26 MISSOURI	
27 MONTANA	
28 NEBRASKA	
29 NEVADA	
30 NEW HAMPSHIRE	
31 NEW JERSEY	
32 NEW MEXICO	
33 NEW YORK	
34 NORTH CAROLINA	
35 NORTH DAKOTA	
36 OHIO	
37 OKLAHOMA	
38 OREGON	
39 PENNSYLVANIA	
40 RHODE ISLAND	
41 SOUTH CAROLINA	
42 SOUTH DAKOTA	
43 TENNESSEE	
44 TEXAS	
45 UTAH	
46 VERMONT	
47 VIRGINIA	
48 WASHINGTON	
49 WEST VIRGINIA	
50 WISCONSIN	
51 WYOMING.

temp.
select if state<21.
cro area by state.

temp.
select if state>20 and state<31.
cro area by state.

temp.
select if state>30 and state<41.
cro area by state.

temp.
select if state>40.
cro area by state.

cro state by regn fone.
rename variables (regn=regionc).
var lab regionc "census region".
val lab regionc 
           1 NORTHEAST
           2 MIDWEST
           3 SOUTH
           4 WEST
          -8 MISSING OR DIRTY ON THE CASE RECORD
          -9 QUESTION NOT ASKED.

recode state (13, 38, 48=0) (7, 20, 22, 30, 40, 46=1) (31,33=2) 
   (8, 9, 21, 39, 47, 49=3) (14, 15, 23, 24, 36, 50=5) 
   (4, 19, 32, 37, 44=6) (16, 18, 26, 28=7) (6, 27, 35, 42, 51=8)
   (3, 5, 29=9) (-8=-8) (else=4) into regione.
var lab regione "EPA REGION".
val lab regione
  -9 "QUESTION NOT ASKED"
  -8 "MISSING OR DIRTY IN THE CASE RECORD"
  0 "MOUNTAIN"
  1 "NEW ENGLAND"
  2 "NORTH ATLANTIC"
  3 "MID ATLANTIC"
  4 "SOUTH ATLANTIC"
  5 "MIDWEST"
  6 "SOUTH CENTRAL"
  7 "CENTER"
  8 "NORTH CENTRAL"
  9 "PACIFIC".
cro state by regione.

recode j4 (8=-8) (3=0) (1,2=1) into urban.
var lab urban URBANICITY OF RESPONDENT'S HOME.
val lab urban 
              0    RURAL
              1    URBAN
             -9    not asked
             -8    missing.
cro j4 by urban.

*********
*INCOME *
*********.
freq hinc.
*labels wrong, check against education to confirm groups
*also labels suggest many categories, but only 3 groups in data.
cro b1 p4 by hinc.

*the three categories in hinc appear to correspond to lower third, middle third and
*upper third of income.
compute income65=-7.
var lab income65 "Total household income 1965-66".
compute income75=-7.
var lab income75 "Total family income 1975-76".
val lab income65 income75
-7 not applicable.
recode hinc (1=4) (3=7) (4=9) into income03.
var lab income03 Household income 2003-2007.
val lab income03
  1 "<$5,000"
  2 $5,000-7,499
  3 $7,500-9,999
  4 $10,000-12,499
  5 $12,500-14,999
  6 $15,000-19,999
  7 $20,000-24,999
  8 $25,000-29,999
  9 $30,000-34,999
 10 $35,000-39,999
 11 $40,000-49,999
 12 $50,000-59,999
 13 $60,000-74,999
 14 $75,000-99,999
 15 $100,000-149,999
 16 "$150,000+"
 -8 missing
 -9 not available.
freq income03.
cro income03 by hinc.

rename variables (hinc=incomeqt).
var lab incomeqt income quartile.
val lab incomeqt 
  1 lowest quartile
  2 2nd lowest quartile
  3 2nd highest quartile
  4 highest quartile
 -8 missing
 -9 cannot be constructed.
freq incomeqt.

***********************
*household composition*
***********************.

freq p5 p6 p7ab.

recode p5 (99=-8) (else=copy) into nadult.
recode p6 (9=-8) (else=copy) into under18.
recode p7ab (9=-8) (sysmis=-8) (else=copy) into under5.
compute ageyngst=-9.
var lab nadult number of adults in hh.
VAR LAB under18 'number of children aged <18 in household'.
VAL LAB UNDER18 under5
             11    MORE THAN 10
             -7    NOT APPLICABLE OR REFUSAL
             -8    MISSING OR DIRTY ON THE CASE RECORD
             -9    QUESTION NOT ASKED.
var lab under5 "number of children aged <5 in household".
var lab ageyngst "age of youngest child".
val lab ageyngst
  -9 "QUESTION NOT ASKED"
  -8 "MISSING OR DIRTY ON THE CASE RECORD"
  -7 "NOT APPLICABLE"
  0 "less THAN 1".

cro under18 by under5.
compute nkidflag=0.
if under5=5 nkidflag=1.
var lab nkidflag "Flag for inconsistencies in numbers between under18 under5 ageyngst".
VAL LAB NKIDFLAG 
           0   OK
           1   more under 5
          -9   Not constructed.

compute kidflag=-7.
var lab kidflag "Cases where inconsistency between household type and number of children was corrected".
VAL LAB KIDFLAG 
          -7  Not constructed
           0  NA
           1  inconsistencies on number kids in heritage file.
freq kidflag nkidflag ageyngst nadult under18 under5.

*****************************
*couple and family variables*
*****************************.

freq p9.
recode p9 (1=1) (2,3=2) (4=3) (5=4) (9=-8) into civstat.
val lab civstat 
      1 married
      2 separated, divorced
      3 widowed
      4 never married
     -8 missing or dirty on the case record
     -9 question not asked.
freq civstat.
cro p9 by civstat.

compute cohab=-9.
var lab cohab with unmarried cohabiting partner.
val lab cohab
   -9 not asked
   -8 missing
    0 no
    1 yes.
freq cohab.

compute marrflag=-9.
var lab marrflag "Flag for 1975 panel change in marital status".
val lab marrflag
   -9 not available
    0 not applicable
    1 got married
    2 no spouse in hhold.

Do if under18=0 and (age>17 and age<40).
   compute famstat=0.
Else if under18=0 and age>39.
   compute famstat=3.
Else if age>17 and under5>0.  
   compute famstat=1.
Else if age>17 and under18>0.  
   compute famstat=2.
*Else if age<18 and parpres=1.
*   compute famstat=4.
*Else if age<18.
*   compute famstat=5.
else.
     compute famstat=-8.
end if.
val lab famstat 
   0    Adult aged 18 to 39 with no coresident children <18
   1    Adult 18+ living with 1+ coresident children aged <5
   2    Adult 18+ living with 1+ coresident children 5-17, none <5
   3    Adult aged 40+ with no coresident children <18
   4    Respondent aged <18 and living with parents or guardians
   5    respondent aged <18 and living in other arrangement
  -8    missing
  -9    could not be constructed.

fre famstat.
cro under5 under18 by famstat.
means ageyngst age by famstat
   /cells = min max. 

compute hhtype=0.
Do if civstat=1 and under18>0.
   compute hhtype=1.
Else if civstat=1 and under18=0.
   compute hhtype=2.
else if sex=1 and civstat>1 and nadult=1 and under18=0.
  compute hhtype=6.
else if sex=2 and civstat>1 and nadult=1 and under18=0.
  compute hhtype=7.
else if sex=2 and under18>0.
  compute hhtype=3.
else if sex=2 and under18=0.
  compute hhtype=4.
else.
compute hhtype=8.
end if.
val lab hhtype  
  1 married with child
  2 married without child
  3 female hh with child
  4 female hh without child
  5 male hh
  6 single male
  7 single female
  8 other
 -8 missing or dirty on the case record
 -9 data not available.
freq hhtype.
cro civstat under18 under5 by hhtype.

************
*EMPLOYMENT*
************.
recode h1 (sysmis=8).
desc act1 act2 act3 act5.
freq h1 b1 b1a.
cro b1a by b1 h1.
cro b1 by h1.

recode b1 (1=1) (else=0) into fulltime.
var lab fulltime "RESPONDENT WORKS FULL TIME".
val lab fulltime
  -8 missing
   0 no
   1 "yes (21+ hrs 65-85; 35+ hrs 92-03)".
recode b1 (2=1) (else=0) into parttime.
var lab parttime "RESPONDENT WORKS PART TIME".
val lab parttime
  -8 missing
   0 no
   1 "yes (<21 hrs 65-85; <35 hrs 92-03)".
fre parttime fulltime.
cro parttime fulltime by b1.

compute noemploy=1.
If h1=1 or b1=1 or b1=2 noemploy=0.
var lab noemploy "RESPONDENT IS NOT EMPLOYED".
val lab noemploy
              0    NO
              1    YES
             -7    NOT APPLICABLE or refusal
             -8    missing or dirty on the case record.
fre noemploy.
cro noemploy by b1 h1.

if fulltime=1 empstat=1.
if parttime=1 empstat=2.
if noemploy=1 empstat=3.
var lab empstat "employment status of respondent".
val lab empstat  
           1 employed full-time
           2 employed part-time
           3 not employed
          -3 routed out in the 1992-94 survey
          -7 not applicable 
          -8 missing or dirty on the case record
          -9 could not be constructed.
freq empstat.
recode empstat (sysmis=-8).
Do if age>65 and empstat=-8.
   compute empstat=2.
   compute parttime=1.
end if.
means age by empstat
   /cells=min max mean.
cro empstat by b1a.
*the remaining -8 cases are people coded as not working as a main economic
*activity, but they have some work, so code these are part-time.
Do if empstat=-8.
   compute empstat=2.
   compute parttime=1.
end if.
freq empstat.

compute unemp=0.
If b1a=3 unemp=1. 
var lab unemp "RESPONDENT IS UNEMPLOYED".
val lab unemp
      0    NO
      1    YES
     -3    routed out in the 1992-94 survey
     -7    not applicable or refusal
     -8    missing or dirty on the case record.
freq unemp.
cro unemp by b1a.

compute retired=0.
if b1a=1 or (age>64 and noemploy=1) retired=1. 
var lab retired "RESPONDENT IS RETIRED".
val lab retired   
  -9 not asked
  -8 missing
  -3 routed out in the 1992-94 survey
   0 no
   1 yes.
fre retired.
cro retired by b1a.

compute student=0.
if b1a=4 or act50>0 student=1. 
var lab student "RESPONDENT IS A STUDENT".
val lab student
      0    NO
      1    YES.
freq student.
cro student by b1a.

compute homemakr=0.
if b1a=2 and retired=0 homemakr=1.
var lab homemakr "RESPONDENT IS A HOMEMAKER".
val lab homemakr 
      0 NO
      1 YES.
freq homemakr.
cro homemakr by b1a.

compute wkhrs=-9.
val lab WKHRS    
    61 BETWEEN 61 AND 80 HOURS
    81 MORE THAN 80 HOURS
    -7 NA   
    -8 MISSING DIRTY IN THE CASE RECORD.
fre WKHRS.

compute nwork=-9. 
var lab NWORK number of hh members working.
compute empflag=-9.
val lab empflag  
    0 OK
    1 work 20hours+
   -9 Not constructed.
compute wkhrflag=-9.
val lab wkhrflag 
   0 OK
   1 hours missing
  -7 NA
  -9 Not constructed.
compute wagelm=-9.
var lab wagelm employment income from last month.
val lab wagelm
   -9 not asked
   -8 missing
   -7 not applicable.
compute empsp=-9.
var lab empsp employment status of spouse or partner.
val lab empsp
-9 not asked in study
-8 item missing
-7 no spouse or not asked
1 spouse works full-time
2 spouse works part-time
3 spouse works, hours unknown
4 spouse not working.
compute occup=-9.
var lab occup occupation.
val lab occup
   -9 not asked in study
   -8 item missing
   -7 not working 
    1 management
    2 finance & accounts
    3 "science (life, physical, social)"
    4 engineer, technical & architecture
    5 community & social services
    6 legal professions
    7 education 
    8 health professionals
    9 other professionals
   10 health care support
   11 protective services
   12 sales
   13 office support, administration
   14 farming, fishing, forestry
   15 services
   16 construction & production
   17 "self-employed non-professional".

************
*DISABILITY*
************.
freq b1a i1 i1a i2 i2a.

compute disab=0.
if b1a=5 or i1a=1 or i2a=1 disab=1.
var lab disab flag for has disability at time of diary.
val lab disab
   0 no
   1 yes.
cro disab by b1a i1a i2a.

************
*ETHNICITY *
************.
freq p2 p3. 

Do if p3=1.
   compute ethnic=1.
Else if p3=2.
   compute ethnic=2.
Else if p3=3.
   compute ethnic=3.
Else if p3>0 and p2=1.
   compute ethnic=5.
Else if p3=4.
   compute ethnic=4.
Else.
   compute ethnic=-8.
End if.    
var lab ethnic "ETHNIC GROUP OF RESPONDENT".
val lab ethnic  
      1 White
      2 Black
      3 Asian
      4 Some other race
      5 Hispanic
     -8 missing
     -9 question not asked.
freq ethnic.
cro ethnic by p2 p3. 

recode ethnic (-8=-8) (1=1) (2=2) (3 thru Highest=3) into ethnic2.
val lab ethnic2
      1 WHITE
      2 BLACK
      3 OTHER
     -8 missing
     -9 question not asked.	
cro ethnic2 by ethnic.

recode p2 (9=-8) (else=copy) into hisp.
val lab hisp
      0  NO
      1  YES
     -1  "DON'T KNOW"
     -8  MISSING OR DIRTY ON THE CASE RECORD.
cro p2 by hisp.

*******
*EDUC *
*******.

freq p4.

recode p4 (99=-8) (0 thru 8=1) (9 thru 11=2) (12=3) (13 thru 15=4) 
       (16=5) (17, 18=6) into educ. 
var lab educ "RESPONDENT'S EDUCATIONAL LEVEL".
val lab educ    
     1 0 - 8TH GRADE
     2 9 - 11TH GRADE
     3 HIGH SCHOOL GRADUATE
     4 SOME COLLEGE
     5 COLLEGE GRADUATE
     6 POST COLLEGE
    -7 REFUSAL or NOT APPLICABLE
    -8 MISSING OR DIRTY ON THE CASE RECORD.
cro p4 by educ.

*********
*housing*
*********.
compute ownhome=-9.
var lab ownhome own or rent home.
val lab ownhome
   -9 not available in survey
   -8 missing
    1 owner or buying home
    2 rent
    3 other.

format all (f4.0).
var lab survey Survey period.
var lab wave Wave of survey.
var lab hhid Household identifier.
var lab pid Person identifier.
var lab state State.
var lab urban urban or rural household.
var lab age Age of diarist.
var lab sex Sex of diarist.
var lab ethnic2 "ethnic group  condensed".
var lab hisp "is respondent of Hispanic origin-descent".
var lab civstat marital status.
var lab famstat Individual life cycle status.
var lab hhtype Household type.
var lab under5 number of children aged <5 in household.
var lab wkhrs Number of hours worked per week. 
var lab empflag "flag for respondent working >20 hours who is defined as not working". 
var lab wkhrflag "flag for work hours missing".
var lab incomeqt Household income in approximate quartiles.

SAVE OUTFILE='C:\Documents and Settings\Kimberly Fisher\My Documents\Kimberly\time\ATUS\AHTUS final files\Harmonised files\Questionnaire\USA94_95quest.sav'
   /keep survey wave hhid pid state regionc regione urban ownhome age sex 
    ethnic ethnic2 hisp educ civstat cohab marrflag famstat hhtype kidflag 
    nadult under18 under5 ageyngst nkidflag fulltime parttime noemploy 
    empstat unemp retired empsp occup disab student homemakr wkhrs nwork 
    empflag wkhrflag wagelm incomeqt income65 income75 income03.

get file='C:\Documents and Settings\Kimberly Fisher\My Documents\Kimberly\time\ATUS\AHTUS final files\Harmonised files\Questionnaire\USA94_95quest.sav'.

freq survey wave state regionc regione ownhome urban age sex 
     ethnic ethnic2 hisp educ civstat cohab marrflag famstat 
     hhtype kidflag nadult under18 under5 ageyngst nkidflag 
     fulltime parttime noemploy empstat empsp occup unemp 
     retired disab student homemakr wkhrs nwork empflag 
     wkhrflag incomeqt income65 income75 income03.

cro empsp by civstat.

desc hhid pid wagelm age.

*temp.
*select if wagelm>-1.
*desc wagelm.
*
*temp.
*select if wagelm<0.
*freq wagelm.
