**********************************************************************
**Syntax producing the USA heritage time use demographic file for	  **
**the 1998-99 FISCT and 1999-01 NSP , written by  Evrim Altintas	   **
**with contributions from Kimberly Fisher & Roger Patulny, Centre 	 **
**for Time Use  Research, Department of Sociology, University of  	 **
**Oxford, Oxford OX1 3UQ United Kingdom                             **
**note that this file only contains the code that makes these       **
**variables, but the code does not necessarily run independently   	**
**the ConvertUSA98TUV.sps file create both the background &     	   **
**time use diary files -                 last updated 05 July 2013  **
**********************************************************************.

*************************************
**COMBINE SURVEYS AND PREPARE DATA**
*************************************.
*initially we tired making unique identifiers using the person and household
*level identifiers, but as the variable survey will distinguish the cases,
*later this work is dropped - in the end the user should note that there are
*some cases of diarists in each survey with the same original personal 
*identifier - but as long as the identifiers distinguish the survey, there
*is not problem.
 
get file ="/Users/evrim/Dx/USA/1998-2001/US_ep98.sav".
compute pide=98000000+pid.
desc pid pide.
compute wave=1.
freq wave.
sort cases by pide.
save outfile ="/Users/evrim/Dx/USA/1998-2001/US_ep98.sav".

get file ="/Users/evrim/Dx/USA/1998-2001/US_ep99.sav".
sort cases by pid.
compute pide=99000000+pid.
desc pid pide.
compute wave=2.
freq wave.
sort cases by pide.
save outfile ="/Users/evrim/Dx/USA/1998-2001/US_ep99.sav".

get file ="/Users/evrim/Dx/USA/1998-2001/US_agg98.sav".
compute pide=98000000+pid.
desc pid pide.
compute wave=1.
sort cases by pide.
save outfile ="/Users/evrim/Dx/USA/1998-2001/US_agg98.sav".


get file ="/Users/evrim/Dx/USA/1998-2001/US_agg99.sav".
sort cases by pid.
compute pide=99000000+pid.
desc pid pide.
compute wave=2.
sort cases by pide.
save outfile ="/Users/evrim/Dx/USA/1998-2001/US_agg99.sav".
*Now all files have one unique personal identifier which is called pide.

*add sex age variable which will be used to check matching and will be included in HEF file.
get file ="/Users/evrim/Dx/USA/1998-2001/US_agg98.sav"
/keep wave pide rsex p3a.
compute age=98-p3a.
freq age rsex.
add files /file=* /file= "/Users/evrim/Dx/USA/1998-2001/US_agg99.sav" /keep wave pide rsex age ageflag ageimp.
execute.
recode age (sysmis=-8) (-1=-8) (else=copy).
desc all.
*In 99-2001 survey there are 387 cases where age is missing (pg. 200).
*The data producers created a variable, ageimp by using predicted values for age for the missing
*cases.
recode ageimp(sysmis=-11) (else=copy).
compute ageimp2=rnd(ageimp).
compute rage=age.
If rage<0 and ageimp>0 rage=ageimp2.
freq rage.
*rage includes both imputed and actual values of age for 99-2001 data.
sort cases by pide.
compute test=0.
if pide=lag(pide)test=1.
freq test.
*all identifiers unique.
sort cases by pide.
save outfile ="/Users/evrim/Dx/USA/1998-2001/temp/98_99agesex.sav" /keep wave pide rage rsex.

get file ="/Users/evrim/Dx/USA/1998-2001/temp/98_99agesex.sav".
freq wave.


*Combined original episode files with age/sex information.
get file ="/Users/evrim/Dx/USA/1998-2001/US_ep98.sav".
rename variables (actbtime actetime location intdate intday=start end where date day).
compute surveye=1998.
add files /file=* /file= "/Users/evrim/Dx/USA/1998-2001/US_ep99.sav".
execute.
recode surveye (sysmis=1999) (else=copy).
freq surveye.
sort cases by surveye pide actno.
match files /file=* /table= "/Users/evrim/Dx/USA/1998-2001/temp/98_99agesex.sav" /by pide.
execute.
sort cases by pide.
save outfile "/Users/evrim/Dx/USA/1998-2001/US_ep98_99.sav" /drop totkidt.




*BACKGROUND VARIABLES FOR 1999-2001 NSP*
****************************************.

get file ="/Users/evrim/Dx/USA/1998-2001/US_agg99.sav" /drop act1 to who0 q1 q2 q3 to q5_f q6 to q20.
desc all.

*WAVE/ SURVEY*
***************.
compute wave=2.
compute survey=8.

*HHID*
******.
compute hhid=pide.

*REGIONC/REGIONE /STATE*
************************.
compute regionc=regn.
*There is  a mismatch between the state labels in the original survey and AHTUS codes.
recode area (41=40) (42=41) (43=42) (44=43) (45=44) (46=45)
             (47=46) (49=47) (50=48) (51=49) (52=50) (53=51) (else=copy) into state.
cro area by state.

recode state (13, 38, 48=0) (7, 20, 22, 30, 40, 46=1) (31,33=2) 
   (8, 9, 21, 39, 47, 49=3) (14, 15, 23, 24, 36, 50=5) 
   (4, 19, 32, 37, 44=6) (16, 18, 26, 28=7) (6, 27, 35, 42, 51=8)
   (3, 5, 29=9) (-8=-8) (else=4) into regione.
cro state by regione.

*URBAN/ OWNHOME*
****************.
compute urban=-9.
compute ownhome=-9.

*SEX/ AGE / AGECAT*
******************.
freq rsex.
compute sex=rsex.

recode age ageimp (sysmis=-8) (else=copy).
freq age ageimp.
*'imputed' age has only 29 missings. 
recode age (18 thru 24=1) (25 thru 34=2) (35 thru 44=3) 
(45 thru 54=4) (55 thru 64=5) (65 thru highest=6) (else=copy) into agecat.
cro age by agecat.
*ageflag.


*ETHNIC2/ ETHNIC/ HISP*
***********************.
recode p7 (2=0) (1=1) (9=-8) into hisp.
execute.

freq p7a.
recode p7a (9=-8) (else=copy) into ethnic.
cro ethnic by hisp.

recode p7a (9=-8) (4=3) (else=copy) into ethnic2.
cro p7a by ethnic2.


*EDUC*
******.
freq p8.
recode p8 (1 thru 8=1)(9 thru 11=2) (12=3) (13 thru 15=4) (16=5) (17, 18 =6) (99=-8) into educ.
cro p8 by educ.
freq educ.

*CIVSTAT/ COHAB/ MARFLAG/ EMPSP*
********************************.
freq P6.
recode p6 (1=1) (2,3=2) (4=3) (5=4) (9=-8) into civstat.
compute cohab=-7.

*This is for 75 diaries only.
compute marrflag=-9.
freq p5a.
recode p5a (sysmis=-7) (9=-8) (3=4)(else=copy) into empsp.
cro p5a by empsp.
cro civstat by empsp.
if civstat=-8 and empsp=-7 empsp=-8.

*NADULT/ UNDER18*
*****************.
freq p1.
recode p1 (99=-8) (else=copy) into nadult.
cro p1 by nadult.

freq p2.
recode p2 (99=-8) (else=copy) into under18.
cro p2 by under18.

*AGE YNGST*
***********.
recode CHILD1_1 CHILD2_1 CHILD3_1 CHILD4_1 CHILD5_1 CHILD6_1 (sysmis=-8) (else=copy).
freq  CHILD1_1 CHILD2_1 CHILD3_1 CHILD4_1 CHILD5_1 CHILD6_1.

*temp.
*select if CHILD1_1=0.
*freq CHILD1_1.
*There are 5 cases with 0 value for age of oldest child but SPS doe snot recognize them?...
*So I will recode them as 1... SPSS being stupid.
If pid=11920 or pid=20899 or pid=21533 or pid=50576 or pid=51508 CHILD1_1=1.

compute test=0.
If child2_1>0 and child2_1>child1_1 test=1.
freq test.
*all must be 0 for all cases.

temp. 
select if test=1.
freq pid.
*60936: an error in the ordering of children by age, youngest child is at the age of 7.
*10836: an error in the ordering of children by age, youngest child is at the age of 6.
*52404: an error in the ordering of children by age, youngest child is at the age of 15.
*53449: an error in the ordering of children by age, youngest child is at the age of 9.
*54034: an error in the ordering of children by age, youngest child is at the age of 10.
*62068: an error in the ordering of children by age, youngest child is at the age of 2.
*11445: an error in the ordering of children by age, youngest child is at the age of 5.
*61682: an error in the ordering of children by age, youngest child is at the age of 5.
*63520: an error in the ordering of children by age, youngest child is at the age of 1.

compute ageyngst=-8.
Do if child6_1>0.
compute ageyngst=child6_1.
Else if child5_1>0.
compute ageyngst=child5_1.
Else if child4_1>0.
compute ageyngst=child4_1.
Else if child3_1>0.
compute ageyngst=child3_1.
Else if child2_1>0.
compute ageyngst=child2_1.
Else if child1_1>0.
compute ageyngst=child1_1.
End if.
freq ageyngst.

*Fix thecases with wrong ordering of children:.
If pid=60936 ageyngst=7.
If pid=10836 ageyngst=6.
If pid=52404 ageyngst=15.
If pid=53449 ageyngst=9.
If pid=54034 ageyngst=10.
If pid=62068 ageyngst=2.
If pid=11445 ageyngst=5.
If pid=61682 ageyngst=5.
If pid=63520 ageyngst=1.
execute.
freq ageyngst.

temp.
select if ageyngst=18.
freq pid.
*54825 reported having one child under age 18 but then reported the age of youngest child as 18!.
*for now I ll code the age of youngest child as 17. But put a note on this in Read Me file.
If pid=54825 ageyngst=17.
freq ageyngst.


*UNDER 5*
********.
recode ageyngst (1 thru 4=1) (5 thru 17=0) (else=copy) into under5.
cro ageyngst by under5.


*FAMSTAT*
*********.
*Because all the respondents were aged 18 or older ANd because
*they all have with at least one co-resident child aged uner 18 
*we actually don't need to use age information to create famstat for this 
*particular survey.


cro ageyngst by under5.
Do if under5>0.  
   compute famstat=1.
Else if ageyngst ~= -8 and under18>0.  
   compute famstat=2.
Else.
     compute famstat=-8.
end if.
cro under5 under18 by famstat.
means ageyngst age by famstat /cells = min max. 


*HHTYPE*
*******.
freq under18.
*We know that all respodents have at least one child aged under 18.
compute hhtype=0.
Do if civstat=1.
compute hhtype=1.
Else if civstat>1 and sex=2.
compute hhtype=3.
Else if civstat>1 and sex=1.
compute hhtype=5.
else.
compute hhtype=-8.
end if.

*KIDFLAG/ NKIDFLAG*
*******************.
compute kidflag=-9.
compute nkidflag=-9.

*54825 reported having one child under age 18 but then reported the age of youngest child as 18

*EMPSTAT / FULLTIME/ PARTTIME/ NOEMPLOY*
****************************************.
freq p3a.
recode p3a (sysmis=-8) (9=-8) (else=copy) into empstat.
cro empstat by p3a p3b.
cro p3b by p3a.

recode empstat (1=1) (else=0) into fulltime.
recode empstat (2=1) (else=0) into parttime.
recode empstat (1,2,=0) (3=1)(else=copy) into noemploy.
cro empstat by fulltime parttime noemploy.

*WORKHRS/ OCCUPATION / WAGELM /NWORK /EMPFLAG/WKHRFLAG *
*********************************************************.
freq p3c_a.
recode p3C_a (sysmis=-7) (99,98=-8) (else=copy) into wkhrs.
cro wkhrs by empstat p3a.
means wkhrs by empstat.
compute occup=-9.
compute wagelm=-9.
compute nwork=-9.
compute empflag=-9.
compute wkhrflag=-9.

*RETIRED/ HOMEMAKER/ STUDENT/ DISAB/UNEMP *
******************************************.
recode p3b (sysmis=-7) (else=copy).
recode p3b (1=1) (else=0) into retired.
cro p3b empstat by retired.

recode p3b (2=1) (else=0) into homemakr.
cro p3b empstat by homemakr.

recode p3b (4=1) (else=0) into student.
cro student by empstat p3b.

recode p3b (5=1) (else=0) into disab.
freq disab.

recode p3b (3=1) (else=0) into unemp.
freq unemp.

*INCOME98 / INCOMEQT*
*********************.
*I am excluding the so-called "imputed" cases according to the crosstabulation of hinc and hincome.
cro HINC by hincome.
compute income98=-8.
Do if hinc=1 and hincome=1.
compute income98=1.
Else if hincome=1 and hinc=4.
compute income98=2.
Else if hincome=2 and hinc=5.
compute income98=3.
else if hincome=3 and hinc=6.
compute income98=4.
else if hincome=4 and hinc=7.
compute income98=5.
else if hincome=5 and hinc=10.
compute income98=6.
else if hincome=6 and hinc=12.
compute income98=7.
end if.
cro income98 by hincome.
cro hinc by income98.
freq income98.

recode income98 (1,2,3=1) (4=2) (5=3) (6,7=4) (-8=-8) into incomeqt.
freq incomeqt.

sort cases by survey wave hhid pid.
save outfile= "/Users/evrim/Dx/USA/1998-2001/temp/99quest.sav"
/keep survey wave hhid pid state regionc regione 
    urban ownhome age sex ethnic ethnic2 hisp educ 
    civstat cohab marrflag famstat hhtype kidflag nadult 
    under18 under5 ageyngst nkidflag fulltime parttime 
    noemploy empstat occup unemp retired empsp disab 
    student homemakr wkhrs nwork empflag wkhrflag 
    wagelm incomeqt income98.

*BACKGROUND VARIABLES FOR 1998-1999 FISCT*
*****************************************.

get file ="/Users/evrim/Dx/USA/1998-2001/US_agg98.sav" /drop fone to b19a_b c1 to q4  q19 to q20h where00 to act99.
desc all.

*WAVE*
******.
compute wave=1.
compute survey=6.

*HHID*
******.
compute hhid=pide.

*SEX/ AGE*
**********.
freq rsex.
rename variables (rsex=sex).

compute age= (date - trunc(date/100)*100)-p3a.
if age=-1 or age=0 age=-8.
freq age.

*compute year= 1900 + (date - trunc(date/100)*100).
*string dates (A6).
*compute dates=string (date,F6.0).

*CIVSTAT/ COHAB/ MARFLAG/ EMPSP*
********************************.
cro P6 by marstat.
recode p6 (1,6=1) (2,3=2) (4=3) (5=4) (9=-8) into civstat.
freq civstat.
recode p6 (6=1) (9=-8) (else=0) into cohab.
cro civstat by cohab.
*there were three cases where a spouse presence was indicated in the diary file.
*original survey coded these as married in a marflag variable. WE will follow
*their procedure.
cro civstat by marstat.
If civstat=4 and marstat=1 civstat=1.
compute marflag=-9.
cro zo_a by civstat.
recode zo_a (0=4) (1 thru 20=2) (21 thru 97=1) (98, 99=-8) (sysmis=-7) into empsp.
If empsp=-7 and civstat=1 empsp=-8.
If civstat=-8 empsp=-8.
cro empsp by civstat.

*EDUC*
******.
recode p5 (0 thru 8=1) (9 thru 11=2) (12=3) (13 thru 15=4) (16=5) (17,18=6) (sysmis=-8) into educ.
cro p5 by educ.

*REGIONC/ REGIONE/ STATE*
*************************.
rename variables (region=regionc).
*There is  a mismatch between the state labels in the original survey and AHTUS codes.
recode state (41=40) (42=41) (43=42) (44=43) (45=44) (46=45)
             (47=46) (49=47) (50=48) (51=49) (52=50) (53=51) (else=copy).
freq state.
recode state (13, 38, 48=0) (7, 20, 22, 30, 40, 46=1) (31,33=2) 
   (8, 9, 21, 39, 47, 49=3) (14, 15, 23, 24, 36, 50=5) 
   (4, 19, 32, 37, 44=6) (16, 18, 26, 28=7) (6, 27, 35, 42, 51=8)
   (3, 5, 29=9) (-8=-8) (else=4) into regione.

*URBAN/ OWNHOME*
****************.
compute urban=-9.
compute ownhome=-9.

*EMPSTAT/FULLTIME/ PARTTIME/ NOEMPLOY/ WORKHRS*
***********************************************.
recode p7 (9=-8) (else=copy) into empstat.
recode empstat (1=1) (-8=-8) (else=0) into fulltime.
recode empstat (2=1) (-8=-8) (else=0) into parttime.
recode empstat (1,2,=0) (3=1) (-8=-8)(else=copy) into noemploy.
recode wrkhrs (sysmis=-7) (98,99=-8)(else=copy) into wkhrs.
freq wrkhrs.


*RETIRED/ HOMEMAKER/ STUDENT/ DISAB/UNEMP *
******************************************.
recode p7a (sysmis=-7) (9=-8) (else=copy).
recode p7a (1=1) (else=0) into retired.
cro p7a empstat by retired.

recode p7a (2=1) (else=0) into homemakr.
cro p7a empstat by homemakr.

recode p7a (4=1) (else=0) into student.
cro student by empstat p7a.

recode p7a (5=1) (else=0) into disab.
freq disab.

recode p7a (3=1) (else=0) into unemp.
freq unemp.

*NADULT/ UNDER18/ UNDER5*
*************************.
recode p1 (99=-8) (else=copy) into nadult.
recode p2 (9=-8) (else=copy) into under18.
freq p2a.
Compute under5=-8.
Do if under18=0.
compute under5=0.
else if p2a=9.
compute under5=-8.
else.
compute under5=p2a.
end if.
*The question is asked only to those who reported at least 1 child under 18.
*P2a asks whether there is a child aged 6 or younger.
cro under18 by under5.
cro nadult by under18.

*FAMSTAT*
*********.
*All the respondents are aged 18 or older. But there are several cases with missing value for age.
freq age under18.
Do if under18=0 and (age>0 and age<40).
   compute famstat=0.
Else if under18=0 and age>39.
   compute famstat=3.
Else if age>0 and under5>0.  
   compute famstat=1.
Else if age>0 and under18>0.  
   compute famstat=2.
else.
     compute famstat=-8.
end if.

temp.
select if age>0.
cro under18 under5 by famstat. 
*55 cases with missing age and 3 casses missing presence of children.

*HHTYPE*
*******.
freq under18.
cro under18 by civstat.

compute hhtype=-99.
Do if under18=-8.
compute hhtype=-8.
else if civstat=1 and under18>0.
compute hhtype=1.
Else if civstat=1 and under18=0.
compute hhtype=2.
Else if civstat>1 and sex=2 and under18>0.
compute hhtype=3.
Else if civstat>1 and sex=2 and under18=0.
compute hhtype=4.
Else if civstat>1 and sex=1 and under18>0.
compute hhtype=5.
Else if civstat>1 and sex=1 and nadult=1.
compute hhtype=6.
Else if sex=2 and civstat>1 and nadult=1.
compute hhtype=7.
Else if sex=2 and civstat>1.
compute hhtype=7.
else.
compute hhtype=8.
end if.

*ETHNIC/ETHNIC2/ HISP*
*********************.
recode p4a (4=3)(sysmis=-8) (else=copy) into ethnic2.
cro p4a by ethnic2.
recode p4 (9=-8) (else=copy) into hisp.
recode p4a (sysmis=-8) (else=copy) into ethnic.
cro ethnic by hisp.

*INCOME 98/ INCOMEQT*
*********************.
recode hincome1 (99=-8) (else=copy) into income98.
cro income98 by hincome1.

recode income98 (1,2,3=1) (4=2) (5=3) (6,7=4) (-8=-8) into incomeqt.
freq incomeqt.

compute occup=-9.
compute wagelm=-9.
compute nwork=-9.
compute empflag=-9.
compute wkhrflag=-9.
compute ageyngst=-7.
compute marrflag=-9.
compute kidflag=-9.
compute nkidflag=-9.


sort cases by survey wave hhid pid.
save outfile= "/Users/evrim/Dropbox/CTUR/USA/1998-2001/temp/98quest.sav"
/keep survey wave hhid pid state regionc regione 
    urban ownhome age sex ethnic ethnic2 hisp educ 
    civstat cohab marrflag famstat hhtype kidflag nadult 
    under18 under5 ageyngst nkidflag fulltime parttime 
    noemploy empstat occup unemp retired empsp disab 
    student homemakr wkhrs nwork empflag wkhrflag 
    wagelm incomeqt income98.

get file= "/Users/evrim/Dropbox/CTUR/USA/1998-2001/temp/99quest.sav".
add files file=* /file="/Users/evrim/Dropbox/CTUR/USA/1998-2001/temp/98quest.sav".
desc all.
*no system missings.
sort cases by hhid.
compute test=0.
if hhid=lag(hhid) test=1.
freq test.

*as the variable survey distinguishes the two surveys, we do not need the altered household id created above
*to make a unique identifier for each case, turn hhid back to = pid.
compute hhid=pid.

*original survey has variables called PID and AGE which are in all caps - as the AHTUS and 
*MTUS variables are in all lower case, address this by renaming the original variables
*and then reconstructing the variables in lower case.

rename variables (pid age=pidorig ageorig).
compute age=ageorig.
compute pid=pidorig.

********
*AGECAT*
********.
recode age (18 thru 24=1) (25 thru 34=2) (35 thru 44=3) (45 thru 54=4) (55 thru 64=5) (65 thru 97=6) (else=copy) into agecat.

formats survey to income98 (f8.0).
apply dictionary from '/Users/evrim/Dropbox/CTUR/USA/questschema.sav'.
execute.

desc all.
freq cohab ageyngst.
var lab cohab "with unmarried cohabiting partner".
val lab cohab
   -9 not asked
   -8 missing or dirty on the case record
   -7 not applicable or refusal 
    0 no
    1 yes.
if age=97 age=92.
compute wave=1.
desc survey wave hhid pid.
freq survey wave state regionc regione urban ownhome 
    age sex ethnic ethnic2 hisp educ 
    civstat cohab marrflag famstat hhtype kidflag nadult 
    under18 under5 ageyngst nkidflag fulltime parttime 
    noemploy empstat occup unemp retired empsp disab 
    student homemakr wkhrs nwork empflag wkhrflag 
    wagelm incomeqt income98.
if survey=6 hhid=hhid-98000000.
if survey=8 hhid=hhid-99000000.
execute.

sort cases by survey wave hhid pid.
save outfile= "/Users/evrim/Dropbox/CTUR/USA/1998-2001/Harmonised Files/usa98_01quest.sav"
/keep  survey wave hhid pid state regionc regione 
    urban ownhome age sex ethnic ethnic2 hisp educ 
    civstat cohab marrflag famstat hhtype kidflag nadult 
    under18 under5 ageyngst nkidflag fulltime parttime 
    noemploy empstat occup unemp retired empsp disab 
    student homemakr wkhrs nwork empflag wkhrflag 
    wagelm incomeqt income98.

get file= "/Users/evrim/Dropbox/CTUR/USA/1998-2001/Harmonised Files/usa98_01quest.sav".
apply dictionary from '/Users/evrim/Dropbox/CTUR/USA/questschema.sav'.

sort cases by survey wave hhid pid.
save outfile "/Users/evrim/Dropbox/CTUR/USA/1998-2001/Harmonised Files/usa98_01quest.sav".




